Crate midnight_base_crypto

Crate midnight_base_crypto 

This crate collects cryptographic primitives used in Midnight’s ledger. All primitives, including zero-knowledge, curve choice, and crypto-aware data structures are defined here, and should be added here to decouple from any specific implementation.

Re-exports

pub use repr::*;

Modules

cost_model
This module contains primitives used in the cost model, including the structures used for costing, the time abstraction used in the cost model, and the arithmetic defined over them.
data_provider
Provides mechanisms to fetch Midnight proof-related parameters and keys.
fab
Defines the primitives of the field-aligned binary representation, where values are represented as sequences of binary strings, that are tied to an alignment which can be used to interpret them either as binary data, or a sequence of field elements for proving.
hash
Hashing functions for use across Midnight.
repr
This module deals with representing data as sequences of binary objects for use in persistent hashing.
rng
Extension traits for specific Rngs.
signatures
Signature scheme for use primarily outside of proofs
time
Representation of time and duration