pub struct FixedPoint(/* private fields */);Expand description
Represents a rational number deterministically. Internally, numbers are
represented by an integer x: i128, which represents the real x / (2 ** 64).
Addition, multiplication, and division are defined; as this is used for cost estimations, addition and multiplication are saturating (because the maximum should always be rejected), and division rounds up.
Implementations
Sourceimpl FixedPoint
impl FixedPoint
Sourcepub const ZERO: FixedPoint
pub const ZERO: FixedPoint
The value of 0.0
Sourcepub const ONE: FixedPoint
pub const ONE: FixedPoint
The value of 1.0
Sourcepub const MIN_POSITIVE: FixedPoint
pub const MIN_POSITIVE: FixedPoint
The smallest positive fraction representable in this fixed point representation
Sourcepub const MAX: FixedPoint
pub const MAX: FixedPoint
The maximum representable fixed point number
Sourcepub fn into_atomic_units(self, base_unit: u128) -> u128
pub fn into_atomic_units(self, base_unit: u128) -> u128
Takes a FixedPoint denominated in a non-base token unit (for instance,
1.0 representing DUST) to it’s base unit.
Conceptually, acts as self * base_unit as u128 with smarter overflow
handling.
Rounds up, and returns zero for negatives.
Sourcepub const fn from_u64_div(a: u64, b: u64) -> FixedPoint
pub const fn from_u64_div(a: u64, b: u64) -> FixedPoint
Instantiates a fixed point from a/b (rounded up to the nearest 2^-64)
Unlike FixedPoint::from_u128_div, this method is const, due to using only builtin
rust arithmetic operations.
Sourcepub fn from_u128_div(a: u128, b: u128) -> FixedPoint
pub fn from_u128_div(a: u128, b: u128) -> FixedPoint
Instantiates a fixed point from a/b (rounded up to the nearest 2^-64)