pub struct MidnightDataProvider {
pub fetch_mode: FetchMode,
pub base_url: Url,
pub output_mode: OutputMode,
pub expected_data: Vec<(&'static str, [u8; 32], &'static str)>,
pub dir: PathBuf,
}Expand description
Retrieves various static cryptographic artifacts from a data server. This keeps a local file system cache of the parameters, prover keys, verifier keys, and IR, that can also be fetched remotely.
The local cache is located at: $MIDNIGHT_PP / $XDG_CACHE_HOME/midnight/zk-params /
$HOME/.cache/midnight/zk-params in that order of fall-backs.
The provider knows which data is in scope, and the SHA-256 hashes of each of these. When reading one of the values from cache, or fetching them, the SHA-256 hash is verified for integrity.
The data provider can operate in an on-demand, or synchronous mode. In the former, if a datum
is not locally available, it is fetched when requested. In the latter, the datum is only
fetched when explicitly requested via a MidnightDataProvider::fetch call. Key material is
always synchronous.
Fields
fetch_mode: FetchModeHow to handle requests to fetch data
base_url: UrlThe base URL of the data store to use.
Fetching an item with name will request it from {base_url}/{name}.
output_mode: OutputModeHow to report status of fetching to the user
expected_data: Vec<(&'static str, [u8; 32], &'static str)>Additional (non-parameter) files allows to be fetched
Triple of file_path, SHA-256 hash, and description
dir: PathBufThe path to the directory where Midnight key material is stored
Implementations