AlignmentAtom

Enum AlignmentAtom 

pub enum AlignmentAtom {
    Compress,
    Bytes {
        length: u32,
    },
    Field,
}
A single alignment entry, typically matching with a field holding a primitive data type.

Variants



Compress

This atom should be represented by its hash in a field representation.



Bytes

This atom has a known binary size of length bytes. Note that the value may be encoded with less, due to omitting trailing zeros.

Fields

length: u32

The length of the atom in bytes.



Field

This atom encodes a native field element.

Implementations

Source

impl AlignmentAtom

pub fn fits(&self, value: &ValueAtom) -> bool

Tests if a ValueAtom fits within the alignment.