pub enum AlignmentSegment {
Atom(AlignmentAtom),
Option(Vec<Alignment>),
}Expand description
An alignment segment in the field-aligned binary encoding. Consists of either an alignment atom, or a disjoint union of alignment options.
Variants
Atom(AlignmentAtom)
A single atom in the alignment, corresponding to a single byte string in the value sequence.
Option(Vec<Alignment>)
A disjoint union of possible alignments, with an implicit domain separator for the variant used.
In the context of defaults, the first option is chosen. If there are no options, the empty value is used. As a result, a default need not type-check.