pub struct Alignment(pub Vec<AlignmentSegment>);Expand description
Encodes an alignment in the field-aligned binary encoding, as a sequence of
AlignmentSegments.
Tuple Fields
0: Vec<AlignmentSegment>Implementations
Sourceimpl Alignment
impl Alignment
Sourcepub fn singleton(pty: AlignmentAtom) -> Alignment
pub fn singleton(pty: AlignmentAtom) -> Alignment
Creates an alignment consisting of just an atom.
Sourcepub fn fits(&self, value: &ValueSlice) -> bool
pub fn fits(&self, value: &ValueSlice) -> bool
Tests if a value fits within an alignment.
Sourcepub fn consume<'a>(
&'a self,
value: &'a ValueSlice,
) -> Option<(AlignedValueSlice<'a>, &'a ValueSlice)>
pub fn consume<'a>( &'a self, value: &'a ValueSlice, ) -> Option<(AlignedValueSlice<'a>, &'a ValueSlice)>
Consumes part of a value with this alignment, returning its aligned form, and the remaining value, if the prefix fits this alignment.
Sourcepub fn concat<'a, I: IntoIterator<Item = &'a Alignment>>(iter: I) -> Alignment
pub fn concat<'a, I: IntoIterator<Item = &'a Alignment>>(iter: I) -> Alignment
Concatenates multiple alignments.