ValueSlice

Struct ValueSlice 

#[repr(transparent)]
pub struct ValueSlice(pub [ValueAtom]);
Borrowed form of Value.

Tuple Fields

0: [ValueAtom]

Implementations

Source

impl ValueSlice

pub fn is_empty(&self) -> bool

Returns is this value is the empty value (not to be confused with an encoding of zero, which is a non-empty value with a single empty entry).