pub struct HashOutput(pub [u8; 32]);Expand description
A wrapper around hash outputs.
Tuple Fields
0: [u8; 32]Trait Implementations
Sourceimpl Aligned for HashOutput
impl Aligned for HashOutput
Sourceimpl BinaryHashRepr for HashOutput
impl BinaryHashRepr for HashOutput
Sourceimpl Clone for HashOutput
impl Clone for HashOutput
Sourcefn clone(&self) -> HashOutput
fn clone(&self) -> HashOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HashOutput
impl Debug for HashOutput
Sourceimpl Default for HashOutput
impl Default for HashOutput
Sourcefn default() -> HashOutput
fn default() -> HashOutput
Returns the “default value” for a type. Read more
Sourceimpl Deserializable for HashOutput
impl Deserializable for HashOutput
Sourceimpl<'de> Deserialize<'de> for HashOutput
impl<'de> Deserialize<'de> for HashOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for HashOutput
impl Display for HashOutput
Sourceimpl Distribution<HashOutput> for Standard
impl Distribution<HashOutput> for Standard
Sourceimpl Dummy<Faker> for HashOutput
impl Dummy<Faker> for HashOutput
Sourceimpl From<HashOutput> for Value
impl From<HashOutput> for Value
Sourcefn from(val: HashOutput) -> Value
fn from(val: HashOutput) -> Value
Converts to this type from the input type.
Sourceimpl From<HashOutput> for ValueAtom
impl From<HashOutput> for ValueAtom
Sourcefn from(hash: HashOutput) -> ValueAtom
fn from(hash: HashOutput) -> ValueAtom
Converts to this type from the input type.
Sourceimpl Hash for HashOutput
impl Hash for HashOutput
Sourceimpl Ord for HashOutput
impl Ord for HashOutput
Sourcefn cmp(&self, other: &HashOutput) -> Ordering
fn cmp(&self, other: &HashOutput) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for HashOutput
impl PartialEq for HashOutput
Sourceimpl PartialOrd for HashOutput
impl PartialOrd for HashOutput
Sourceimpl Serializable for HashOutput
impl Serializable for HashOutput
Sourceimpl Serialize for HashOutput
impl Serialize for HashOutput
Sourceimpl Tagged for HashOutput
impl Tagged for HashOutput
Sourcefn tag() -> Cow<'static, str>
fn tag() -> Cow<'static, str>
Retrieves the tag of
Self. Returns a [Cow] as type arguments require allocation, but no
allocation is preferred.Sourcefn tag_unique_factor() -> String
fn tag_unique_factor() -> String
A decomposition of this tag into primitive types (any type whose representation is not
defined through other types), tuples (via
(a,b)), and sum types (via [a,b]). Read moreSourceimpl TryFrom<&ValueAtom> for HashOutput
impl TryFrom<&ValueAtom> for HashOutput
Sourcetype Error = InvalidBuiltinDecode
type Error = InvalidBuiltinDecode
The type returned in the event of a conversion error.
Sourcefn try_from(value: &ValueAtom) -> Result<HashOutput, InvalidBuiltinDecode>
fn try_from(value: &ValueAtom) -> Result<HashOutput, InvalidBuiltinDecode>
Performs the conversion.
Sourceimpl TryFrom<&ValueSlice> for HashOutput
impl TryFrom<&ValueSlice> for HashOutput
Sourcetype Error = InvalidBuiltinDecode
type Error = InvalidBuiltinDecode
The type returned in the event of a conversion error.
Sourcefn try_from(value: &ValueSlice) -> Result<HashOutput, InvalidBuiltinDecode>
fn try_from(value: &ValueSlice) -> Result<HashOutput, InvalidBuiltinDecode>
Performs the conversion.
Sourceimpl Zeroize for HashOutput
impl Zeroize for HashOutput
impl Copy for HashOutput
impl Eq for HashOutput