pub enum AlignmentAtom {
Compress,
Bytes {
length: u32,
},
Field,
}Expand description
A single alignment entry, typically matching with a field holding a primitive data type.
Variants
Compress
This atom should be represented by its hash in a field representation.
Bytes
This atom has a known binary size of length bytes. Note that the value
may be encoded with less, due to omitting trailing zeros.
Field
This atom encodes a native field element.
Implementations